pub trait MemRequest {
// Required methods
fn address(&self) -> u64;
fn req_id(&self) -> u16;
fn tag(&self) -> u8;
fn ldwbe(&self) -> u8;
fn fdwbe(&self) -> u8;
}Expand description
Memory Request Trait: Applies to 32 and 64 bits requests as well as legacy IO-Request (Legacy IO Request has the same structure as MemRead3DW) Software using the library may want to use trait instead of bitfield structures Both 3DW (32-bit) and 4DW (64-bit) headers implement this trait 3DW header is also used for all Legacy IO Requests.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".